package com.ruoyi.business.service.impl;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ruoyi.business.domain.bo.ListRebotBO;
import com.ruoyi.business.domain.vo.ListRebotVO;
import com.ruoyi.business.util.YinDaoHttpUtils;
import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.utils.SecurityUtils;
import org.springframework.stereotype.Service;
import com.ruoyi.business.mapper.RebotMapper;
import com.ruoyi.business.domain.Rebot;
import com.ruoyi.business.service.IRebotService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.transaction.annotation.Transactional;

/**
 * 机器人管理Service业务层处理
 *
 * @author LiuChengRan
 * @date 2024-06-13
 */
@Service
public class RebotServiceImpl extends ServiceImpl<RebotMapper, Rebot> implements IRebotService {


    /**
     * 同步机器人数据
     *
     * @return
     */
    @Override
    @DataScope(deptAlias = "d", userAlias = "u")
    @Transactional
    public void syn(Rebot entity) {
        ListRebotBO listRebotBO = new ListRebotBO();
        listRebotBO.setPage(1);
        listRebotBO.setSize(10000);
        List<Rebot> rebotsList = baseMapper.selectRebotList(new Rebot());
        Map<String, List<Rebot>> rebotMap = rebotsList.stream().collect(Collectors.groupingBy(Rebot::getRobotClientName));

        List<ListRebotVO> listRebotVoList = YinDaoHttpUtils.listRebot(listRebotBO);
        // 获取客户端名称集合
        List<String> clientNameList = listRebotVoList.stream().map(ListRebotVO::getRobotClientName).collect(Collectors.toList());
        this.remove(new LambdaUpdateWrapper<Rebot>().notIn(Rebot::getRobotClientName, clientNameList).eq(Rebot::getDeptId, SecurityUtils.getDeptId()));
        listRebotVoList.forEach(listRebotVO -> {
            // 数据库里是否存在
            List<Rebot> rebots = rebotMap.get(listRebotVO.getRobotClientName());
            if (null == rebots) {
                Rebot rebot = new Rebot();
                rebot.setStatus(listRebotVO.getStatus());
                rebot.setRobotClientUuid(listRebotVO.getRobotClientUuid());
                rebot.setRobotClientName(listRebotVO.getRobotClientName());
                rebot.setWindowsAccount(listRebotVO.getWindowsAccount());
                rebot.setClientIp(listRebotVO.getClientIp());
                rebot.setDeptId(SecurityUtils.getDeptId());
                save(rebot);
            } else {
                Rebot rebot = rebots.get(0);
                rebot.setStatus(listRebotVO.getStatus());
                rebot.setRobotClientUuid(listRebotVO.getRobotClientUuid());
                rebot.setRobotClientName(listRebotVO.getRobotClientName());
                rebot.setWindowsAccount(listRebotVO.getWindowsAccount());
                rebot.setClientIp(listRebotVO.getClientIp());
                rebot.setDeptId(SecurityUtils.getDeptId());
                updateById(rebot);
            }
        });
    }

    /**
     * 查询机器人管理列表
     *
     * @param rebot 机器人管理
     * @return 机器人管理
     */
    @Override
    public List<Rebot> list(Rebot rebot) {
        return baseMapper.selectRebotList(rebot);
    }
}
